==> apache-camel-4.3.0-src.zip: apache-camel-4.3.0/components/camel-aws/camel-aws-config/src/main/java/org/apache/camel/component/aws/config/client/AWSConfigClientFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws.config.client;

import org.apache.camel.component.aws.config.AWSConfigConfiguration;
import org.apache.camel.component.aws.config.client.impl.AWSConfigClientIAMOptimizedImpl;
import org.apache.camel.component.aws.config.client.impl.AWSConfigClientIAMProfileOptimizedImpl;
import org.apache.camel.component.aws.config.client.impl.AWSConfigClientStandardImpl;

/**
 * Factory class to return the correct type of AWS Config client.
 */
public final class AWSConfigClientFactory {

    private AWSConfigClientFactory() {
    }

    /**
     * Return the correct AWS Config client (based on remote vs local).
     *
     * @param  configuration configuration
     * @return               ConfigClient
     */
    public static AWSConfigInternalClient getConfigClient(AWSConfigConfiguration configuration) {
        if (Boolean.TRUE.equals(configuration.isUseDefaultCredentialsProvider())) {
            return new AWSConfigClientIAMOptimizedImpl(configuration);
        } else if (Boolean.TRUE.equals(configuration.isUseProfileCredentialsProvider())) {
            return new AWSConfigClientIAMProfileOptimizedImpl(configuration);
        } else {
            return new AWSConfigClientStandardImpl(configuration);
        }
    }
}

==> apache-camel-4.15.0-src.zip: apache-camel-4.15.0/components/camel-aws/camel-aws-config/src/main/java/org/apache/camel/component/aws/config/client/AWSConfigClientFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws.config.client;

import org.apache.camel.component.aws.config.AWSConfigConfiguration;
import org.apache.camel.component.aws.config.client.impl.AWSConfigClientIAMOptimizedImpl;
import org.apache.camel.component.aws.config.client.impl.AWSConfigClientIAMProfileOptimizedImpl;
import org.apache.camel.component.aws.config.client.impl.AWSConfigClientSessionTokenImpl;
import org.apache.camel.component.aws.config.client.impl.AWSConfigClientStandardImpl;

/**
 * Factory class to return the correct type of AWS Config client.
 */
public final class AWSConfigClientFactory {

    private AWSConfigClientFactory() {
    }

    /**
     * Return the correct AWS Config client (based on remote vs local).
     *
     * @param  configuration configuration
     * @return               ConfigClient
     */
    public static AWSConfigInternalClient getConfigClient(AWSConfigConfiguration configuration) {
        if (Boolean.TRUE.equals(configuration.isUseDefaultCredentialsProvider())) {
            return new AWSConfigClientIAMOptimizedImpl(configuration);
        } else if (Boolean.TRUE.equals(configuration.isUseProfileCredentialsProvider())) {
            return new AWSConfigClientIAMProfileOptimizedImpl(configuration);
        } else if (Boolean.TRUE.equals(configuration.isUseSessionCredentials())) {
            return new AWSConfigClientSessionTokenImpl(configuration);
        } else {
            return new AWSConfigClientStandardImpl(configuration);
        }
    }
}
